# Generated by Django 2.0.5 on 2020-03-12 09:22

from decimal import Decimal
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('mbills', '0002_auto_20171011_1507'),
    ]

    operations = [
        migrations.AddField(
            model_name='mbillstransaction',
            name='refunded',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='mbillstransaction',
            name='refunded_amount',
            field=models.DecimalField(decimal_places=2, default=Decimal('0'), max_digits=20),
        ),
    ]
